@@ -188,7 +188,7 @@ gnome_print_copies_selector_class_init (GnomePrintCopiesSelectorClass *klass)
 						G_SIGNAL_RUN_FIRST,
 						G_STRUCT_OFFSET (GnomePrintCopiesSelectorClass, copies_set),
 						NULL, NULL,
-						libgnomeprintui_marshal_INT__INT_BOOLEAN,
+						libgnomeprintui_marshal_VOID__INT_BOOLEAN,
 						G_TYPE_NONE,
 						2,
 						G_TYPE_INT, G_TYPE_BOOLEAN);
@@ -257,6 +257,7 @@ gnome_print_copies_selector_init (GnomePrintCopiesSelector *gpc)
 
 	adj = (GtkAdjustment *) gtk_adjustment_new(1, 1, 1000, 1.0, 10.0, 10.0);
 	gpc->copies = gtk_spin_button_new (adj, 1.0, 0);
+	gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (gpc->copies), TRUE);
 	gtk_widget_show (gpc->copies);
 	gtk_table_attach_defaults ((GtkTable *)table, gpc->copies, 1, 2, 0, 1);
 
