@@ -511,6 +511,13 @@ preview_canvas_key (GtkWidget *widget, GdkEventKey *event, gpointer data)
 	case GDK_Escape:
 		gtk_widget_destroy (GTK_WIDGET (pmp));
 		return TRUE;
+	case GDK_q:
+	case GDK_w:
+		if (event->state & GDK_CONTROL_MASK) {
+			gtk_widget_destroy (GTK_WIDGET (pmp));
+			return TRUE;		
+		}
+	        /* break skipped */
 	default:
 		return FALSE;
 	}
@@ -724,16 +731,10 @@ create_toplevel (GnomePrintJobPreview *mp)
 	GPMPPrivate *priv;
 	GtkWidget *tb;
 	gint width, height;
+	GdkGeometry hints;
 
 	priv = (GPMPPrivate *) mp->priv;
 
-	width  = MIN (mp->paw + PAGE_PAD * 3, gdk_screen_width () - 40);
-	height = MIN (mp->pah + PAGE_PAD * 3, gdk_screen_height () - 40);
-
-	gtk_widget_set_size_request (GTK_WIDGET (mp), width, height);
-
-	/* This is not very beautiful, but works for now */
-
 	tb = gtk_toolbar_new ();
 	gtk_toolbar_set_style (GTK_TOOLBAR (tb), GTK_TOOLBAR_ICONS);
 	gtk_widget_show (tb);
@@ -768,6 +769,22 @@ create_toplevel (GnomePrintJobPreview *mp)
 					    GTK_SIGNAL_FUNC (gpmp_zoom_in_cmd), mp, -1);
 	mp->bzo = gtk_toolbar_insert_stock (GTK_TOOLBAR (tb), GTK_STOCK_ZOOM_OUT, _("Zooms the page out"), "", 
 					    GTK_SIGNAL_FUNC (gpmp_zoom_out_cmd), mp, -1);
+
+	width  = MIN (mp->paw + PAGE_PAD * 3, gdk_screen_width () * 3 / 4);
+	height = MIN (mp->pah + PAGE_PAD * 3, gdk_screen_height () * 3 / 4);
+
+	hints.base_width = mp->paw;
+        hints.base_height = mp->pah;
+        hints.min_width = 150;
+        hints.min_height = 150;
+	
+	gtk_window_set_default_size (&(mp->window),
+				     width, 
+				     height);
+	gtk_window_set_geometry_hints 
+		(&(mp->window), priv->scrolled_window,
+		 &hints, GDK_HINT_MIN_SIZE | GDK_HINT_BASE_SIZE);
+
 }
 
 /*
