@@ -33,6 +33,7 @@
 
 #include "gnome-print-i18n.h"
 #include "gnome-printer-selector.h"
+#include <libgnomeprint/gnome-print-config.h>
 
 #include "gpaui/gpa-printer-selector.h"
 #include "gpaui/gpa-settings-selector.h"
@@ -91,6 +92,25 @@ gnome_printer_selector_init (GObject *object)
 {
 }
 
+static void
+gnome_printer_selector_config_modified_cb (GPANode *node, guint flags, GnomePrinterSelector *gpw)
+{
+	gchar *printer = gpa_node_get_path_value (node, "Printer");
+
+	if (printer != NULL) {
+		gtk_label_set_text (GTK_LABEL (gpw->state), "");
+		gtk_label_set_text (GTK_LABEL (gpw->type), "");
+                gtk_label_set_text (GTK_LABEL (gpw->comment),"");
+		g_free (printer);
+	}
+}
+
+typedef struct {
+	GObject parent;
+	GPANode *node;
+} myGnomePrintConfig;
+
+
 static gint
 gnome_printer_selector_construct (GPAWidget *gpa_widget)
 {
@@ -99,7 +119,7 @@ gnome_printer_selector_construct (GPAWidget *gpa_widget)
 	AtkRelationSet *relation_set;
 	AtkRelation *relation;
 	AtkObject *relation_targets[2];
-	AtkObject *atko, *label_atko, *menu_atko, *entry_atko;
+	AtkObject *atko, *label_atko, *menu_atko, *button_atko;
 
 	gpw = GNOME_PRINTER_SELECTOR (gpa_widget);
 
@@ -119,19 +139,37 @@ gnome_printer_selector_construct (GPAWidget *gpa_widget)
 	gtk_box_pack_start (GTK_BOX (h), t, FALSE, TRUE, 0);
 	gtk_container_add (GTK_CONTAINER (f), h);
 
-	gpw->type = gpw_create_label (GTK_TABLE (t), 1, 2, 3, 4, "", NULL);
-	gpw_create_label (GTK_TABLE (t), 0, 1, 3, 4, _("State:"), gpw->type);
+	gpw->state = gpw_create_label (GTK_TABLE (t), 1, 2, 3, 4, "", NULL);
+	gpw_create_label (GTK_TABLE (t), 0, 1, 3, 4, _("State:"), gpw->state);
+	gtk_misc_set_alignment (GTK_MISC (gpw->state), 0.0, 0.5);
 
-	gpw->location = gpw_create_label (GTK_TABLE (t), 1, 2, 4, 5, "", NULL);
-	gpw_create_label (GTK_TABLE (t), 0, 1, 4, 5, _("Type:"), gpw->location);
+	gpw->type = gpw_create_label (GTK_TABLE (t), 1, 2, 4, 5, "", NULL);
+	gpw_create_label (GTK_TABLE (t), 0, 1, 4, 5, _("Type:"), gpw->type);
+	gtk_misc_set_alignment (GTK_MISC (gpw->type), 0.0, 0.5);
 
 	gpw->comment = gpw_create_label (GTK_TABLE (t), 1, 2, 5, 6, "", NULL);
 	gpw_create_label (GTK_TABLE (t), 0, 1, 5, 6, _("Comment:"), gpw->comment);
+	gtk_misc_set_alignment (GTK_MISC (gpw->comment), 0.0, 0.5);
 
 	b = gtk_button_new_with_mnemonic (_("Co_nfigure"));
 	gtk_widget_show (b);
 	g_signal_connect (G_OBJECT (b), "clicked",
 			  (GCallback) gpw_configure_clicked, gpw);
+
+	if (GPA_WIDGET(gpw)->config == NULL) {
+		gpw->handler_config = 0;
+		g_warning ("gnome-printer-selector config not set!");
+	} else {
+		GPANode *n 
+			= ((myGnomePrintConfig *)
+			   GPA_WIDGET(gpw)->config)->node;
+		gpw->handler_config  = g_signal_connect
+			(G_OBJECT(n),
+			 "modified", (GCallback)
+			 gnome_printer_selector_config_modified_cb, gpw);
+		gnome_printer_selector_config_modified_cb (n, 0, gpw);
+	}
+
 	gtk_table_attach (GTK_TABLE (t), b, 2, 3, 1, 2,
 			  GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL,
 			  GPS_PAD, GPS_PAD);
@@ -167,15 +205,14 @@ gnome_printer_selector_construct (GPAWidget *gpa_widget)
 	gpw_create_label_with_mnemonic (GTK_TABLE (t), 0, 1, 2, 3,
 					_("_Location:"),
 					((GPATransportSelector*) gpw->transport)->menu, FALSE);
-	/* Add a LABEL_FOR relation from the Location label to the option menu
-	   and the entry. */
+	/* Add a LABEL_FOR relation from the Location label to the option menu */
 	label_atko = gtk_widget_get_accessible (l);
 	menu_atko  = gtk_widget_get_accessible (((GPATransportSelector*) gpw->transport)->menu);
-	entry_atko = gtk_widget_get_accessible (((GPATransportSelector*) gpw->transport)->file_entry);
+	button_atko = gtk_widget_get_accessible (((GPATransportSelector*) gpw->transport)->file_button);
 
 	relation_set = atk_object_ref_relation_set (label_atko);
 	relation_targets[0] = menu_atko;
-	relation_targets[1] = entry_atko;
+	relation_targets[1] = button_atko;
 	relation = atk_relation_new (relation_targets, 2,
 				     ATK_RELATION_LABEL_FOR);
 	atk_relation_set_add (relation_set, relation);
@@ -191,7 +228,7 @@ gnome_printer_selector_construct (GPAWidget *gpa_widget)
 	g_object_unref (G_OBJECT (relation));
 	g_object_unref (G_OBJECT (relation_set));
 
-	relation_set = atk_object_ref_relation_set (entry_atko);
+	relation_set = atk_object_ref_relation_set (button_atko);
 	relation_targets[0] = label_atko;
 	relation = atk_relation_new (relation_targets, 1,
 				     ATK_RELATION_LABELLED_BY);
@@ -209,6 +246,14 @@ gnome_printer_selector_finalize (GObject *object)
 	
 	gpw = GNOME_PRINTER_SELECTOR (object);
 
+	if (gpw->handler_config) {
+		g_signal_handler_disconnect 
+			(G_OBJECT (((myGnomePrintConfig *)
+				    GPA_WIDGET(gpw)->config)->node), 
+			 gpw->handler_config);  
+		gpw->handler_config = 0;
+	}
+
 	if (gpw->accel_group) {
 		g_object_unref (G_OBJECT (gpw->accel_group));
 		gpw->accel_group = NULL;
@@ -287,7 +332,6 @@ gpw_create_label (GtkTable *table, gint l, gint r, gint t, gint b, const gchar *
 					     ATK_RELATION_LABEL_FOR);
 		atk_relation_set_add (relation_set, relation);
 		g_object_unref (G_OBJECT (relation));
-		g_object_unref (G_OBJECT (relation_targets[0]));
 		g_object_unref (G_OBJECT (relation_set));
 
 		/* Add a LABELLED_BY relation from the mnemonic widget to the
@@ -299,7 +343,6 @@ gpw_create_label (GtkTable *table, gint l, gint r, gint t, gint b, const gchar *
 					     ATK_RELATION_LABELLED_BY);
 		atk_relation_set_add (relation_set, relation);
 		g_object_unref (G_OBJECT (relation));
-		g_object_unref (G_OBJECT (relation_targets[0]));
 		g_object_unref (G_OBJECT (relation_set));
 	}
 
@@ -331,7 +374,6 @@ gpw_create_label_with_mnemonic (GtkTable *table, gint l, gint r, gint t, gint b,
 					     ATK_RELATION_LABELLED_BY);
 		atk_relation_set_add (relation_set, relation);
 		g_object_unref (G_OBJECT (relation));
-		g_object_unref (G_OBJECT (relation_targets[0]));
 		g_object_unref (G_OBJECT (relation_set));
 	}
 
