@@ -47,7 +47,7 @@ static gboolean gpa_printer_selector_construct (GPAWidget *gpa);
 
 static GPAWidgetClass *parent_class;
 
-GtkType
+GType
 gpa_printer_selector_get_type (void)
 {
 	static GType type = 0;
